@@ -1,7 +1,7 @@
 %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
 %
 %  Adapter file for JIProlog 4.1.6.1 or later versions
-%  Last updated on May 13, 2018
+%  Last updated on June 18, 2018
 %
 %  This file is part of Logtalk <https://logtalk.org/>  
 %  Copyright 1998-2018 Paulo Moura <pmoura@logtalk.org>
@@ -108,6 +108,7 @@
 
 % '$lgt_prolog_meta_predicate'(@callable, ?callable, ?atom)
 
+'$lgt_prolog_meta_predicate'(*->(_, _), *->(0, 0), control_construct) :- !.
 '$lgt_prolog_meta_predicate'(Callable, Template, predicate) :-
 	predicate_property(Callable, meta_predicate(Template)),
 	predicate_property(Callable, built_in),
@@ -217,6 +218,7 @@
 '$lgt_default_flag'(trivial_goal_fails, warning).
 '$lgt_default_flag'(always_true_or_false_goals, warning).
 '$lgt_default_flag'(lambda_variables, warning).
+'$lgt_default_flag'(suspicious_calls, warning).
 '$lgt_default_flag'(underscore_variables, dont_care).
 % optional features compilation flags:
 '$lgt_default_flag'(complements, deny).
