@@ -1,7 +1,7 @@
 %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
 %
 %  Adapter file for SICStus Prolog 4.1.0 and later versions
-%  Last updated on May 13, 2018
+%  Last updated on June 18, 2018
 %
 %  This file is part of Logtalk <https://logtalk.org/>  
 %  Copyright 1998-2018 Paulo Moura <pmoura@logtalk.org>
@@ -287,6 +287,7 @@ forall(Generate, Test) :-
 '$lgt_default_flag'(trivial_goal_fails, warning).
 '$lgt_default_flag'(always_true_or_false_goals, warning).
 '$lgt_default_flag'(lambda_variables, warning).
+'$lgt_default_flag'(suspicious_calls, warning).
 :- if((current_prolog_flag(version_data, sicstus(Major,Minor,_,_,_)), (Major,Minor) @>= (4,3))).
 	'$lgt_default_flag'(underscore_variables, dont_care).
 :- else.
@@ -745,9 +746,10 @@ forall(Generate, Test) :-
 % '$lgt_normalize_error_term'(@callable, -callable)
 
 '$lgt_normalize_error_term'(
-	error(existence_error(procedure, ':'(user, Functor/Arity)), Context),
-	error(existence_error(procedure, Functor/Arity), Context)
-).
+	error(existence_error(procedure, Module:Predicate), Context),
+	error(existence_error(procedure, Predicate), Context)
+) :-
+	'$lgt_user_module_qualification'(Predicate, Module:Predicate).
 
 
 
