@@ -49,9 +49,9 @@ comment
 	extends(parent)).
 
 	:- info([
-		version is 1.34,
+		version is 1.38,
 		author is 'Paulo Moura',
-		date is 2016/06/18,
+		date is 2017/11/27,
 		comment is 'Sample prototype for testing syntax coloring.'
 	]).
 
@@ -103,7 +103,7 @@ comment
 
 	:- private(ccc/2).
 	:- dynamic(ccc/2).
-	:- mode(ccc(@atom, ?atom), one_or_more).
+	:- mode(ccc(@atom, ?atom, ++list, --ground), one_or_more).
 	:- info(ccc/2, [
 		comment is 'Predicate brief description.',
 		argnames is ['Arg1', 'Arg2']
@@ -180,6 +180,7 @@ comment
 		create_logtalk_flag(Flag, Value, Options).
 
 	execution_context_methods :-
+		context(Context),
 		parameter(N, Parameter),
 		self(Self),
 		sender(Sender),
@@ -190,7 +191,7 @@ comment
 		predicate_property(Predicate, Property).
 
 	database_methods :-
-		abolish(Functor/Arity),
+		abolish(Name/Arity),
 		asserta(Clause),
 		assertz(Clause),
 		clause(Head, Body),
@@ -199,7 +200,15 @@ comment
 
 	exception_methods :-
 		catch(Goal, Error, Catcher),
-		throw(Error).
+		throw(Error),
+		instantiation_error,
+		type_error(Type, Culprit),
+		domain_error(Domain, Culprit),
+		existence_error(Thing, Culprit),
+		permission_error(Operation, Permission, Culprit),
+		representation_error(Flag),
+		evaluation_error(Exception),
+		resource_error(Resource).
 
 	all_solutions_methods :-
 		bagof(Term, Goal, List),
@@ -304,7 +313,7 @@ comment
 		Term1 @> Term2.
 
 	term_creation_and_decomposition :-
-		functor(Term, Functor, Arity),
+		functor(Term, Name, Arity),
 		arg(N, Term, Arg),
 		Term =.. [Functor| Args],
 		copy_term(Term, Copy),
