@@ -13,9 +13,9 @@ __all__ = ['LogtalkLexer']
 
 class LogtalkLexer(RegexLexer):
     """
-    For `Logtalk <http://logtalk.org/>`_ source code.
+    For `Logtalk <https://logtalk.org/>`_ source code.
 
-    :copyright: 2008-2016 by Paulo Moura, Clara Dimene.
+    :copyright: 2008-2017 by Paulo Moura, Clara Dimene.
     :license: BSD, see LICENSE for more details.
     """
 
@@ -47,7 +47,7 @@ class LogtalkLexer(RegexLexer):
             # Message forwarding handler
             (r'forward(?=[(])', Keyword),
             # Execution-context methods
-            (r'(parameter|this|se(lf|nder))(?=[(])', Keyword),
+            (r'(context|parameter|this|se(lf|nder))(?=[(])', Keyword),
             # Reflection
             (r'(current_predicate|predicate_property)(?=[(])', Keyword),
             # DCGs and term expansion
@@ -72,7 +72,8 @@ class LogtalkLexer(RegexLexer):
             (r'a(bolish|ssert(a|z))(?=[(])', Keyword),
             # Control constructs
             (r'(ca(ll|tch)|throw)(?=[(])', Keyword),
-            (r'(fa(il|lse)|true)\b', Keyword),
+            (r'(fa(il|lse)|true|instantiation_error)\b', Keyword),
+            (r'(type|domain|existence|permission|representation|evaluation|resource)_error(?=[(])', Keyword),
             # All solutions
             (r'((bag|set)of|f(ind|or)all)(?=[(])', Keyword),
             # Multi-threading predicates
