@@ -1,12 +1,12 @@
-#!/bin/bash
+#!/usr/bin/env bash
 
 #############################################################################
 ## 
-##   This file is part of Logtalk <http://logtalk.org/>  
-##   Copyright 1998-2016 Paulo Moura <pmoura@logtalk.org>
+##   This file is part of Logtalk <https://logtalk.org/>  
+##   Copyright 1998-2018 Paulo Moura <pmoura@logtalk.org>
 ## 
 ##   Reference Manual XHTML to PDF conversion script
-##   Last updated on August 2, 2016
+##   Last updated on January 25, 2018
 ##   
 ##   Licensed under the Apache License, Version 2.0 (the "License");
 ##   you may not use this file except in compliance with the License.
@@ -127,11 +127,13 @@ eval $xslt_proc -o predicates/logtalk_load_1.section refman.xsl predicates/logta
 eval $xslt_proc -o predicates/logtalk_load_2.section refman.xsl predicates/logtalk_load_2.html
 eval $xslt_proc -o predicates/logtalk_make_0.section refman.xsl predicates/logtalk_make_0.html
 eval $xslt_proc -o predicates/logtalk_make_1.section refman.xsl predicates/logtalk_make_1.html
+eval $xslt_proc -o predicates/logtalk_make_target_action_1.section refman.xsl predicates/logtalk_make_target_action_1.html
 eval $xslt_proc -o predicates/logtalk_library_path_2.section refman.xsl predicates/logtalk_library_path_2.html
 eval $xslt_proc -o predicates/logtalk_load_context_2.section refman.xsl predicates/logtalk_load_context_2.html
 eval $xslt_proc -o predicates/current_logtalk_flag_2.section refman.xsl predicates/current_logtalk_flag_2.html
 eval $xslt_proc -o predicates/set_logtalk_flag_2.section refman.xsl predicates/set_logtalk_flag_2.html
 eval $xslt_proc -o predicates/create_logtalk_flag_3.section refman.xsl predicates/create_logtalk_flag_3.html
+eval $xslt_proc -o methods/context_1.section refman.xsl methods/context_1.html
 eval $xslt_proc -o methods/parameter_2.section refman.xsl methods/parameter_2.html
 eval $xslt_proc -o methods/self_1.section refman.xsl methods/self_1.html
 eval $xslt_proc -o methods/sender_1.section refman.xsl methods/sender_1.html
@@ -151,6 +153,14 @@ eval $xslt_proc -o methods/once_1.section refman.xsl methods/once_1.html
 eval $xslt_proc -o methods/not_1.section refman.xsl methods/not_1.html
 eval $xslt_proc -o methods/catch_3.section refman.xsl methods/catch_3.html
 eval $xslt_proc -o methods/throw_1.section refman.xsl methods/throw_1.html
+eval $xslt_proc -o methods/instantiation_error_0.section refman.xsl methods/instantiation_error_0.html
+eval $xslt_proc -o methods/type_error_2.section refman.xsl methods/type_error_2.html
+eval $xslt_proc -o methods/domain_error_2.section refman.xsl methods/domain_error_2.html
+eval $xslt_proc -o methods/existence_error_2.section refman.xsl methods/existence_error_2.html
+eval $xslt_proc -o methods/permission_error_3.section refman.xsl methods/permission_error_3.html
+eval $xslt_proc -o methods/representation_error_1.section refman.xsl methods/representation_error_1.html
+eval $xslt_proc -o methods/evaluation_error_1.section refman.xsl methods/evaluation_error_1.html
+eval $xslt_proc -o methods/resource_error_1.section refman.xsl methods/resource_error_1.html
 eval $xslt_proc -o methods/bagof_3.section refman.xsl methods/bagof_3.html
 eval $xslt_proc -o methods/findall_3.section refman.xsl methods/findall_3.html
 eval $xslt_proc -o methods/findall_4.section refman.xsl methods/findall_4.html
@@ -274,12 +284,14 @@ cat -s \
 	predicates/logtalk_load_2.section \
 	predicates/logtalk_make_0.section \
 	predicates/logtalk_make_1.section \
+	predicates/logtalk_make_target_action_1.section \
 	predicates/logtalk_library_path_2.section \
 	predicates/logtalk_load_context_2.section \
 	predicates/current_logtalk_flag_2.section \
 	predicates/set_logtalk_flag_2.section \
 	predicates/create_logtalk_flag_3.section \
 	methods.header \
+	methods/context_1.section \
 	methods/parameter_2.section \
 	methods/self_1.section \
 	methods/sender_1.section \
@@ -299,6 +311,14 @@ cat -s \
 	methods/not_1.section \
 	methods/catch_3.section \
 	methods/throw_1.section \
+	methods/instantiation_error_0.section \
+	methods/type_error_2.section \
+	methods/domain_error_2.section \
+	methods/existence_error_2.section \
+	methods/permission_error_3.section \
+	methods/representation_error_1.section \
+	methods/evaluation_error_1.section \
+	methods/resource_error_1.section \
 	methods/bagof_3.section \
 	methods/findall_3.section \
 	methods/findall_4.section \
